function B = B_approx(k,lags,T,n,d) 

%B_APPROX -- Approximate base-level learning equation, parametric depth K
%
% B = B_approx(k,lags,T,n,d)
%
% K is an integer specifying the number of exact terms in the equation.
% Use K=0 for the crudest approximation (Anderson & Lebiere, 1998, p.124),
% K=1 for the approximation used in the ANCHOR model (Petrov & Anderson,
% 2005, Psych Review). K=Inf is equivalent to the exact formula BASE_ACT.
%
% LAGS is a matrix of lags from the present, sorted with the most recent
% ones on top. Each column represents the usage history of a chunk.
% At least K exact values must be supplied. The more distant history may
% be omitted, in which case T and N must be supplied. (In other words, 
% LAGS must have at least K rows but need not be the full history.)
% Missing lags must be filled with Inf.
% T is a row vector specifying the lifetime of each chunk. When not
% supplied, it defaults to the maximal finite element in each column.
% N is a row vector specifying the total number of uses of each chunk.
% It defaults to the number of finite elements in each column.
% When not supplied, the decay parameter D defaults to 0.5.
% The result B is a row vector of base-level activations, one per chunk.
%
% Example:
%  N=10 ; T=100 ; lags=repmat(Inf,N,4) ;
%  lags(:,1)=[1:N]'.*(T/N) ; lags(:,2)=([1:N]'.^2).*(T/N^2) ;
%  lags(1:5,3)=[.2:.2:1]'.*T; lags(1:2,4)=[1 2].*T ;
%  for k=0:N  B=B_approx(k,lags);fprintf('\n%2d ',k);fprintf(' %7.4f',B);end
%    0   0.6931  0.6931  0.0000 -1.2629
%    1   0.5210  0.9694 -0.2531 -1.6991
%    2   0.4980  1.0415 -0.2887 -1.7678
%    3   0.4867  1.0682 -0.3062 -1.7678
%    4   0.4797  1.0786 -0.3172 -1.7678
%    5   0.4748  1.0818 -0.3249 -1.7678
%    6   0.4712  1.0818 -0.3249 -1.7678
%    7   0.4683  1.0804 -0.3249 -1.7678
%    8   0.4659  1.0784 -0.3249 -1.7678
%    9   0.4640  1.0764 -0.3249 -1.7678
%   10   0.4623  1.0747 -0.3249 -1.7678
%
% See also BASE_ACT, PLOT_ACT.

% Original coding by Alexander Petrov, http://alexpetrov.com.
% $Revision: 1.2 $  $Date: 2006/02/10 18:30 $

if (nargin<5)  d = 0.5 ;  end  % ACT-R default decay

[N_lags,N_chunks] = size(lags) ;
nn = sum(isfinite(lags),1) ;   % number of non-Inf lags

if (nargin<4)  n = [] ; end    % n not supplied?
if (isempty(n))
    n = nn ;
end

if (k>=max(n))    % exact solution requested?
    B = base_act(lags,d) ;
    return
end

if (nargin<3)  T = [] ; end    % T not supplied?
if (isempty(T))
    lags1 = lags ;
    lags1(find(isinf(lags))) = -Inf ;    % convert all Inf's to -Inf's
    T = max(lags1,[],1) ;
end

%-- Exact term
if (k>0)
    Bex = sum(lags(1:k,:).^-d,1) ;       % as in BASE_ACT
    tk = lags(k,:) ;
else
    Bex = zeros(1,N_chunks) ;
    tk = zeros(1,N_chunks) ;
end

%disp([Bex;tk;T;n]);

%-- Approximate term
Bap = zeros(1,N_chunks) ;   % some chunks may not need approximation
idx = find(n>k) ;             % find those that do
if (~isempty(idx))
    %- Collect the necessary information
    tk = tk(idx) ;
    T = T(idx) ;
    n = n(idx) ;
    one_d = 1 - d ;
    %- The real work
    approx = T .^ one_d - tk .^ one_d ;
    approx = approx .* ((n-k)./one_d) ;
    Bap(idx) = approx ./ (T - tk) ;
end

B = log(Bex + Bap) ;

%---  Return B
%%%%% End of B_APPROX.M
