function B = base_act(lags,d)

%BASE_ACT   Base-level activation of instances in declarative memory.
%
% B = base_act(lags,d)
%
% Implements the base-level learning equation of ACT-R:
%   B = log(sum(lags .^ -d))
% See Eq. 4.1 at p.124 of the "Atomic Components of Thought"
%
% LAGS is a matrix of lags from the present. Each column represents the
% usage history of a chunk. Missing values must be filled with Inf.
% When not supplied, the decay parameter D defaults to 0.5.
% The result B is a row vector of base-level activations, one per chunk.
%
% Example 1 (Chunks with equal number of uses but different lifetimes):
%  N = 10 ; lags1 = sort(rand(N,1).*100) ; lags2 = sort(rand(N,1).*200) ;
%  B = base_act([lags1 lags2])   ==>  B = [0.7125 0.0927]
%
% Example 2:
%  T=100 ; lags=[[1:N]'./N,[1:N]'.^2./N^2].*T ; B=base_act(lags)
%  B = 0.4623 1.0747
%
% See also B_APPROX, PLOT_ACT.

% Original coding by Alexander Petrov, http://alexpetrov.com.
% $Revision: 1.2 $  $Date: 2006/02/10 17:14 $

if (nargin<2)  d = 0.5 ;  end  % ACT-R default decay

B = log(sum(lags .^ -d)) ;

%---  Return B
%%%%% End of BASE_ACT.M
