function [B,lags] = plot_act(refs,grid,k,d)

%PLOT_ACT -- Base-level activation plots at different approximation depths
%
% B = plot_act(refs,grid,k,d)
%
% REFS is a column vector of reference time stamps, in increasing order.
% GRID is a Tx1 vector defining the temporal grid for the plot.
% K is a row vector of approximation depths. Each value generates
% an approximation curve according to B_APPROX over the GRID.
% D is a decay parameter passed to B_APPROX. Default = B_APPROX's default.
% The result B is a matrix with T rows and length(K) columns.
%
% Example: 
%  k=[Inf 2 1 0];l={'exact','k=2','k=1','k=0'};Nk=length(k);
%  grid=[0.1:0.5:70]';
%  refs{1}=[0:5:50]';ttl{1}='uniform';
%  refs{2}=(refs{1}.^2)./50;ttl{2}='accelerating';
%  refs{3}=49.9-flipud(refs{2});ttl{3}='decelerating';
%  plot(cat(2,refs{:}),'.-');legend(ttl{:});
%  for p=1:3 
%    B{p}=plot_act(refs{p},grid,k);
%    err{p}=B{p} - repmat(B{p}(:,1),1,Nk);
%    subplot(3,2,3*p-2);plot(grid,B{p});title(ttl{p});
%    subplot(3,2,3*p-1);plot(grid,err{p});legend(l{:},4);
%  end
%
% See also BASE_ACT, B_APPROX.

% Original coding by Alexander Petrov, http://alexpetrov.com.
% $Revision: 2.0 $  $Date: 2006/02/10 17:52 $

decay_supplied_p = (nargin==4) ;
N_refs = length(refs) ;
N_grid = length(grid) ;
N_k = length(k) ;

%-- Convert references to lags
lags = repmat(Inf,N_refs,N_grid) ;
for t = 1:N_grid
    curr_time = grid(t) ;
    max_idx = max(find(refs<curr_time)) ;
    relevant_refs = flipud(refs(1:max_idx)) ;   % most recent on top
    lags(1:max_idx,t) = curr_time - relevant_refs ;
end

%-- Approximate at different depths k
B = repmat(NaN,N_grid,N_k) ;
if (decay_supplied_p)
    for t = 1:N_k  B(:,t) = B_approx(k(t),lags,[],[],d)' ; end
else
    for t = 1:N_k  B(:,t) = B_approx(k(t),lags)' ; end
end     

plot(grid,B) ;


%---  Return B (and LAGS)
%%%%% End of PLOT_ACT.M
